#
# spec file for package python-mako
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define modname Mako

Name:           python-mako
Version:        0.7.3
Release:        1.2
Summary:        A Super-Fast Templating Language
Url:            http://www.makotemplates.org/
License:        MIT
Group:          Development/Libraries/Python
Source:         %{modname}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{py_requires}
BuildRequires:  python-devel
BuildRequires:  python-setuptools
%if 0%{?suse_version} >= 1030
BuildRequires:  fdupes
%endif
Requires:       python-beaker >= 1.1
Requires:       python-markupsafe
%if %{?suse_version: %{suse_version} > 1110} %{!?suse_version:1}
BuildArch:      noarch
%endif

%description
Mako is a template library written in Python. It provides a familiar, non-XML
syntax which compiles into Python modules for maximum performance. Mako's
syntax and API borrows from the best ideas of many others, including Django
templates, Cheetah, Myghty, and Genshi. Conceptually, Mako is an embedded
Python (i.e. Python Server Page) language, which refines the familiar ideas
of componentized layout and inheritance to produce one of the most
straightforward and flexible models available, while also maintaining close
ties to Python calling and scoping semantics.

Authors:
--------
    Mike Bayer <mike@zzzcomputing.com>

%prep
%setup -q -n %{modname}-%{version}

%build
export CFLAGS="$RPM_OPT_FLAGS"
python setup.py build

%install
python setup.py install --single-version-externally-managed --prefix=%{_prefix} --root=$RPM_BUILD_ROOT --record-rpm=INSTALLED_FILES
%if 0%{?suse_version} >= 1030
%fdupes %buildroot
%endif

%clean
rm -rf %{buildroot}

%files -f INSTALLED_FILES
%defattr(-,root,root)
%doc doc examples CHANGES LICENSE

%changelog
* Fri Jan 25 2013 cs@linux-administrator.com
- Update to 0.7.3
* Thu Jul  1 2010 jfunk@funktronics.ca
- Update to 0.3.4
  - Now using MarkupSafe for HTML escaping,
    i.e. in place of cgi.escape().  Faster
    C-based implementation and also escapes
    single quotes for additional security.
    Supports the __html__ attribute for
    the given expression as well.
    When using "disable_unicode" mode,
    a pure Python HTML escaper function
    is used which also quotes single quotes.
    Note that Pylons by default doesn't
    use Mako's filter - check your
    environment.py file.
  - Fixed call to "unicode.strip" in
    exceptions.text_error_template which
    is not Py3k compatible.  [ticket:137]
* Tue Sep  8 2009 jfunk@funktronics.ca
- Update to 0.2.5
  - Added a "decorator" kw argument to <%%def>, allows custom decoration
    functions to wrap rendering callables.  Mainly intended for custom caching
    algorithms, not sure what other uses there may be (but there may be).
    Examples are in the "filtering" docs.
  - When Mako creates subdirectories in which to store templates, it uses the
    more permissive mode of 0775 instead of 0750, helping out with certain
    multi-process scenarios. Note that the mode is always subject to the
    restrictions of the existing umask. [ticket:101]
  - Fixed namespace.__getattr__() to raise AttributeError on attribute not
    found instead of RuntimeError.  [ticket:104]
  - Added last_modified accessor to Template, returns the time.time() when the
    module was created. [ticket:97]
  - Fixed lexing support for whitespace around '=' sign in defs. [ticket:102]
  - Removed errant "lower()" in the lexer which was causing tags to compile
    with case-insensitive names, thus messing up custom <%%call> names.
    [ticket:108]
  - added "mako.__version__" attribute to the base module.  [ticket:110]
* Thu Sep  3 2009 matejcik@suse.cz
- build as noarch
* Thu Sep  3 2009 matejcik@suse.cz
- importing package from OBS, original changelog follows
* Mon Aug 10 2009 Ciaran Farrell <cfarrell1980@gmail.com> - 0.2.4-1
- Update to 0.2.4
* Tue Dec  2 2008 James Oakley <jfunk@funktronics.ca> - 0.2.3-1
- Initial release
